@@ -4,6 +4,11 @@ library("listenv")
 message("*** batchjobs_*() - w/ job.delay ...")
 
 strategies <- c("batchjobs_interactive", "batchjobs_local", "batchjobs_custom")
+
+## CRAN processing times:
+## On Windows 32-bit, don't run these tests
+if (!fullTest && isWin32) strategies <- character(0L)
+
 for (strategy in strategies) {
   plan(strategy)
   a %<-% { 42 }
